Welcome to Django Chuck’s documentation! — Django Chuck 0.1 documentation

### Navigation

- index
- next |
- Django Chuck 0.1 documentation »

# Welcome to Django Chuck’s documentation!

Django Chuck is a modular, open source, command-based project build system developed by Notch Interactive GmbH, that gives you the power to create new projects as fast as pushing on a button.

It creates a virtualenv and a Django project for you, installs all required Python packages, creates the database and a fab file for automatic deployment and thanks to the module system you can easily add functionality like CMS, Facebook, Twitter, multilang and search engine support to a new or existing project.

But Chuck cannot be just used to create a project it can also checkout the source for you and setup everything until the Django server is running and you’re ready to do your development work. Just leave all the annoying stuff to Chuck and if there is some task Chuck can’t do for you at the moment you can add your own command to let Chuck configure your continuous integration system, setup your hosting or do whatever you might imagine!

Currently supported version control systems are: CVS, Subversion, GIT and Mercurial.

## Getting Started

- 1. Installation
  - 1.1. Requirements
  - 1.2. Recommended
  - 1.3. Installation per pip
  - 1.4. Installation via source code
  - 1.5. Configuration
  - 1.6. Module aliases
- 2. Basic commands
  - 2.1. Build a new project
  - 2.2. Setup an existing project
- 3. Project structure
  - 3.1. What’s all that stuff?!
  - 3.2. Requirements
  - 3.3. Settings structure
  - 3.4. Testing
  - 3.5. Continuous integration
  - 3.6. Deployment
- 4. Available modules
- 5. Additional module repositories

## Customizations

- Changing the default module set
- Overriding modules
- Change project structure
- chuck_setup.py
- Writing templates
- Add your own modules
- Module dependencies
- Module post-build-actions
- Write your own command
- Write your own template engine

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- Django Chuck 0.1 documentation »